@@ -1,11 +1,14 @@
 
 # Imports
 import os
-import time
 import shutil
+import time
+from zipfile import ZIP_DEFLATED, ZipFile, ZipInfo
+
 import stouputils as stp
+
 from .io import FILES_TO_WRITE
-from zipfile import ZipFile, ZipInfo, ZIP_DEFLATED
+
 
 # Function that makes an archive with consistency (same zip file each time)
 def make_archive(source: str, destination: str, copy_destinations: list[str] = []) -> float:
